#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# SPDX-License-Identifier: GPL-3.0-or-later
"""
CLI interface for ✉️💣 **LetterBomb**.

----

-h, --help            show this help message and exit
-v, --version         show program's version number and exit
-b, --bundle          pack the HackMii installer into archive
-l LOGFILE, --logfile LOGFILE
                      filepath to put log output
-g {debug,info,warn,error,critical}, --loglevel {debug,info,warn,error,critical}
                      minimum logging level
"""
import argparse
import letterbomb

if __name__ == "__main__":
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "-v",
        "--version",
        action="version",
        version=f"{letterbomb.__project__} v" f"{letterbomb.__version__}",
    )
    parser.add_argument("mac", help="string of Wii's MAC address")
    parser.add_argument(
        "region", choices=letterbomb.REGION_LIST, help="single-letter of Wii's region"
    )
    parser.add_argument("outfile", help="filename of ZIP archive")
    parser.add_argument(
        "-b",
        "--bundle",
        action="store_true",
        help="pack the HackMii installer into archive",
    )
    parser.add_argument(
        "-i",
        "--io-bytes",
        action="store_true",
        help="return bytes I/O instead",
    )
    parser.add_argument("-l", "--logfile", help="filepath to put log output")
    parser.add_argument(
        "-g",
        "--loglevel",
        help="minimum logging level",
        choices=letterbomb.LOGGING_DICT.keys(),
        default="info",
    )

    vargs = vars(parser.parse_args())
    LOGGING_LEVEL = letterbomb.LOGGING_DICT[vargs["loglevel"]]
    if LOGGING_LEVEL == letterbomb.logging.DEBUG:
        print(vargs)
    if vargs["logfile"]:
        LOGGING_FILE = letterbomb.pathlib.Path(vargs["logfile"]).expanduser()
    if vargs["io-bytes"]:
        letterbomb.write_stream(vargs["mac"], vargs["region"], vargs["bundle"])
    letterbomb.write_zip(
        vargs["mac"], vargs["region"], vargs["bundle"], vargs["outfile"]
    )



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# SPDX-License-Identifier: GPL-3.0-or-later
"""Flask configuration."""

# Where to save logfile, can be an absolute or relative path
# Leave blank to not generate a log file
LOG_FILE: str = ""

# Fill these in if you intend on having a Captcha.
# Leave both of these blank if you do not want to include a captcha
RECAPTCHA_PUBLICKEY: str = ""
RECAPTCHA_PRIVATEKEY: str = ""

# Don't enable unless you know what you are doing
DEBUG: bool = False



#!/usr/bin/env python3
# coding=utf-8
"""
Setup.py for Letterbomb.

For usage with `pip install`.
See ``README.md`` for instructions.
"""
from setuptools import setup, find_packages

import letterbomb

try:
    with open("README.md") as f:
        long_description: str = f.read()
except OSError:
    long_description: str = 'Unable to read "README.md"'
    print(long_description)

setup(
    name=letterbomb.__project__.lower(),
    version=letterbomb.__version__,
    author=letterbomb.__author__,
    author_email="4616947-whoatemybutter@users.noreply.gitlab.com",
    maintainer=letterbomb.__author__,
    maintainer_email="4616947-whoatemybutter@users.noreply.gitlab.com",
    url=letterbomb.__url__,
    description="A fork of the classic Wii hacking tool from fail0verflow",
    long_description=long_description,
    long_description_content_type="text/markdown",
    include_package_data=True,
    packages=find_packages(),
    download_url=letterbomb.__download__,
    license="GPLv3+",
    classifiers=[
        "Operating System :: OS Independent",
        "Development Status :: 5 - Production/Stable",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Topic :: Games/Entertainment"
    ],
    python_requires=">=3.6",
    platforms=["any"]
)
